<?php

namespace Wave\Http\Controllers;

use App\Http\Controllers\Controller;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Carbon\Carbon;

// app/Http/Controllers/SpendingController.php

class SpendingController extends Controller
{
    public function index(Request $request)
    {
        $awardTypes = ['Contracts', 'Contract IDVs', 'Grants', 'Direct Payments', 'Loans', 'Other'];
        $financialYears = range(date('Y'), 2000, -1);

        return view('theme::spending.index', compact('awardTypes', 'financialYears'));
    }

    public function search(Request $request)
    {
        $defaultFilters = [
            'filters' => [
                'time_period' => [
                    [
                        'start_date' => '2023-10-01',
                        'end_date' => '2024-09-30',
                        'date_type' => 'new_awards_only',
                    ],
                ],
                'award_type_codes' => ['A', 'B', 'C', 'D'],
            ],
            'fields' => [
                'Award ID',
                'Recipient Name',
                'Start Date',
                'End Date',
                'Award Amount',
                'Total Outlays',
                'Description',
                'def_codes',
                'COVID-19 Obligations',
                'COVID-19 Outlays',
                'Infrastructure Obligations',
                'Infrastructure Outlays',
                'Awarding Agency',
                'Awarding Sub Agency',
                'Contract Award Type',
                'recipient_id',
                'prime_award_recipient_id',
            ],
            'page' => 1,
            'limit' => 60,
            'sort' => 'Award Amount',
            'order' => 'desc',
            'subawards' => false,
        ];
        // $payload = [
        //     'type' => 'budget_function',
        //     'filters' => $request->except('_token'),
        // ];

        // Make API request with the payload
        $response = Http::post('https://api.usaspending.gov/api/v2/spending/', $defaultFilters);

        $data = $response->json();

        return view('theme::spending.search', compact('data'));
        
        //return view('theme::dashboard.index', ['data' => $data]);
    }
}
